
# Enum: QuantityEnum




URI: [nwb_schema_language:QuantityEnum](https://w3id.org/p2p_ld/nwb-schema-language/QuantityEnum)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| * | Zero or more instances, equivalent to zero_or_many |  |  |
| ? | Zero or one instances, equivalent to zero_or_one |  |  |
| + | One or more instances, equivalent to one_or_many |  |  |
| zero_or_many | Zero or more instances, equivalent to * |  |  |
| one_or_many | One or more instances, equivalent to + |  |  |
| zero_or_one | Zero or one instances, equivalent to ? |  |  |

